summaryrefslogtreecommitdiff
path: root/src/ide
diff options
context:
space:
mode:
authorLaurenz <laurmaedje@gmail.com>2022-12-22 18:25:29 +0100
committerLaurenz <laurmaedje@gmail.com>2022-12-22 18:25:29 +0100
commit8527517258cf62a2f229796cc3f118d8bf0494b6 (patch)
tree7662e90bcb9d610e63f4b1a9f1f12f84cb1f742a /src/ide
parent947522b71aa6220ce8f006bfab4700d6e3cb04f1 (diff)
Rename `desc` to `terms`
Diffstat (limited to 'src/ide')
-rw-r--r--src/ide/complete.rs10
-rw-r--r--src/ide/highlight.rs10
2 files changed, 10 insertions, 10 deletions
diff --git a/src/ide/complete.rs b/src/ide/complete.rs
index 27b81fb2..e069391f 100644
--- a/src/ide/complete.rs
+++ b/src/ide/complete.rs
@@ -712,25 +712,25 @@ impl<'a> CompletionContext<'a> {
self.snippet_completion(
"list item",
"- ${item}",
- "Inserts an item of an unordered list.",
+ "Inserts an item of a bullet list.",
);
self.snippet_completion(
"enumeration item",
"+ ${item}",
- "Inserts an item of an ordered list.",
+ "Inserts an item of a numbered list.",
);
self.snippet_completion(
"enumeration item (numbered)",
"${number}. ${item}",
- "Inserts an explicitly numbered item of an ordered list.",
+ "Inserts an explicitly numbered list item.",
);
self.snippet_completion(
- "description list item",
+ "term list item",
"/ ${term}: ${description}",
- "Inserts an item of a description list.",
+ "Inserts an item of a term list.",
);
self.snippet_completion(
diff --git a/src/ide/highlight.rs b/src/ide/highlight.rs
index ff9b8450..1f52ae95 100644
--- a/src/ide/highlight.rs
+++ b/src/ide/highlight.rs
@@ -23,9 +23,9 @@ pub enum Category {
Ref,
/// A section heading.
Heading,
/// A marker of a list, enumeration, or description list.
ListMarker,
- /// A term in a description list.
+ /// A term in a term list.
ListTerm,
/// The delimiters of a math formula.
MathDelimiter,
@@ -114,7 +114,7 @@ pub fn highlight(node: &LinkedNode) -> Option<Category> {
_ => Category::Operator,
}),
SyntaxKind::Slash => Some(match node.parent_kind() {
- Some(SyntaxKind::DescItem) => Category::ListMarker,
+ Some(SyntaxKind::TermItem) => Category::ListMarker,
Some(SyntaxKind::Frac) => Category::MathOperator,
_ => Category::Operator,
}),
@@ -159,7 +159,7 @@ pub fn highlight(node: &LinkedNode) -> Option<Category> {
SyntaxKind::From => Some(Category::Keyword),
SyntaxKind::Markup { .. }
- if node.parent_kind() == Some(&SyntaxKind::DescItem)
+ if node.parent_kind() == Some(&SyntaxKind::TermItem)
&& node.next_sibling().as_ref().map(|v| v.kind())
== Some(&SyntaxKind::Colon) =>
{
@@ -183,7 +183,7 @@ pub fn highlight(node: &LinkedNode) -> Option<Category> {
SyntaxKind::ListItem => None,
SyntaxKind::EnumItem => None,
SyntaxKind::EnumNumbering(_) => Some(Category::ListMarker),
- SyntaxKind::DescItem => None,
+ SyntaxKind::TermItem => None,
SyntaxKind::Math => None,
SyntaxKind::Atom(_) => None,
SyntaxKind::Script => None,
@@ -23,9 +23,9 @@ pub enum Category {
/// A section heading.
Heading,
- /// A marker of a list, enumeration, or description list.
+ /// A marker of a list, enumeration, or term list.
ListMarker,